# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .add_packages_to_software_source_details import AddPackagesToSoftwareSourceDetails
from .api_error import ApiError
from .attach_child_software_source_to_managed_instance_details import AttachChildSoftwareSourceToManagedInstanceDetails
from .attach_parent_software_source_to_managed_instance_details import AttachParentSoftwareSourceToManagedInstanceDetails
from .autonomous_settings import AutonomousSettings
from .available_software_source_summary import AvailableSoftwareSourceSummary
from .available_update_summary import AvailableUpdateSummary
from .available_windows_update_summary import AvailableWindowsUpdateSummary
from .change_managed_instance_group_compartment_details import ChangeManagedInstanceGroupCompartmentDetails
from .change_scheduled_job_compartment_details import ChangeScheduledJobCompartmentDetails
from .change_software_source_compartment_details import ChangeSoftwareSourceCompartmentDetails
from .crash_event_system_information import CrashEventSystemInformation
from .create_managed_instance_group_details import CreateManagedInstanceGroupDetails
from .create_scheduled_job_details import CreateScheduledJobDetails
from .create_software_source_details import CreateSoftwareSourceDetails
from .detach_child_software_source_from_managed_instance_details import DetachChildSoftwareSourceFromManagedInstanceDetails
from .detach_parent_software_source_from_managed_instance_details import DetachParentSoftwareSourceFromManagedInstanceDetails
from .erratum import Erratum
from .erratum_summary import ErratumSummary
from .event import Event
from .event_collection import EventCollection
from .event_content import EventContent
from .event_report import EventReport
from .event_summary import EventSummary
from .id import Id
from .installable_package_summary import InstallablePackageSummary
from .installed_package_summary import InstalledPackageSummary
from .installed_windows_update_summary import InstalledWindowsUpdateSummary
from .kernel_crash_event import KernelCrashEvent
from .kernel_oops_event import KernelOopsEvent
from .kernel_vm_core_information import KernelVmCoreInformation
from .managed_instance import ManagedInstance
from .managed_instance_group import ManagedInstanceGroup
from .managed_instance_group_summary import ManagedInstanceGroupSummary
from .managed_instance_summary import ManagedInstanceSummary
from .package_name import PackageName
from .recurrence import Recurrence
from .related_event_collection import RelatedEventCollection
from .related_event_summary import RelatedEventSummary
from .remove_packages_from_software_source_details import RemovePackagesFromSoftwareSourceDetails
from .scheduled_job import ScheduledJob
from .scheduled_job_summary import ScheduledJobSummary
from .software_package import SoftwarePackage
from .software_package_dependency import SoftwarePackageDependency
from .software_package_file import SoftwarePackageFile
from .software_package_search_summary import SoftwarePackageSearchSummary
from .software_package_summary import SoftwarePackageSummary
from .software_source import SoftwareSource
from .software_source_id import SoftwareSourceId
from .software_source_summary import SoftwareSourceSummary
from .update_event_details import UpdateEventDetails
from .update_managed_instance_details import UpdateManagedInstanceDetails
from .update_managed_instance_group_details import UpdateManagedInstanceGroupDetails
from .update_scheduled_job_details import UpdateScheduledJobDetails
from .update_software_source_details import UpdateSoftwareSourceDetails
from .windows_update import WindowsUpdate
from .windows_update_summary import WindowsUpdateSummary
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for os_management services.
os_management_type_mapping = {
    "AddPackagesToSoftwareSourceDetails": AddPackagesToSoftwareSourceDetails,
    "ApiError": ApiError,
    "AttachChildSoftwareSourceToManagedInstanceDetails": AttachChildSoftwareSourceToManagedInstanceDetails,
    "AttachParentSoftwareSourceToManagedInstanceDetails": AttachParentSoftwareSourceToManagedInstanceDetails,
    "AutonomousSettings": AutonomousSettings,
    "AvailableSoftwareSourceSummary": AvailableSoftwareSourceSummary,
    "AvailableUpdateSummary": AvailableUpdateSummary,
    "AvailableWindowsUpdateSummary": AvailableWindowsUpdateSummary,
    "ChangeManagedInstanceGroupCompartmentDetails": ChangeManagedInstanceGroupCompartmentDetails,
    "ChangeScheduledJobCompartmentDetails": ChangeScheduledJobCompartmentDetails,
    "ChangeSoftwareSourceCompartmentDetails": ChangeSoftwareSourceCompartmentDetails,
    "CrashEventSystemInformation": CrashEventSystemInformation,
    "CreateManagedInstanceGroupDetails": CreateManagedInstanceGroupDetails,
    "CreateScheduledJobDetails": CreateScheduledJobDetails,
    "CreateSoftwareSourceDetails": CreateSoftwareSourceDetails,
    "DetachChildSoftwareSourceFromManagedInstanceDetails": DetachChildSoftwareSourceFromManagedInstanceDetails,
    "DetachParentSoftwareSourceFromManagedInstanceDetails": DetachParentSoftwareSourceFromManagedInstanceDetails,
    "Erratum": Erratum,
    "ErratumSummary": ErratumSummary,
    "Event": Event,
    "EventCollection": EventCollection,
    "EventContent": EventContent,
    "EventReport": EventReport,
    "EventSummary": EventSummary,
    "Id": Id,
    "InstallablePackageSummary": InstallablePackageSummary,
    "InstalledPackageSummary": InstalledPackageSummary,
    "InstalledWindowsUpdateSummary": InstalledWindowsUpdateSummary,
    "KernelCrashEvent": KernelCrashEvent,
    "KernelOopsEvent": KernelOopsEvent,
    "KernelVmCoreInformation": KernelVmCoreInformation,
    "ManagedInstance": ManagedInstance,
    "ManagedInstanceGroup": ManagedInstanceGroup,
    "ManagedInstanceGroupSummary": ManagedInstanceGroupSummary,
    "ManagedInstanceSummary": ManagedInstanceSummary,
    "PackageName": PackageName,
    "Recurrence": Recurrence,
    "RelatedEventCollection": RelatedEventCollection,
    "RelatedEventSummary": RelatedEventSummary,
    "RemovePackagesFromSoftwareSourceDetails": RemovePackagesFromSoftwareSourceDetails,
    "ScheduledJob": ScheduledJob,
    "ScheduledJobSummary": ScheduledJobSummary,
    "SoftwarePackage": SoftwarePackage,
    "SoftwarePackageDependency": SoftwarePackageDependency,
    "SoftwarePackageFile": SoftwarePackageFile,
    "SoftwarePackageSearchSummary": SoftwarePackageSearchSummary,
    "SoftwarePackageSummary": SoftwarePackageSummary,
    "SoftwareSource": SoftwareSource,
    "SoftwareSourceId": SoftwareSourceId,
    "SoftwareSourceSummary": SoftwareSourceSummary,
    "UpdateEventDetails": UpdateEventDetails,
    "UpdateManagedInstanceDetails": UpdateManagedInstanceDetails,
    "UpdateManagedInstanceGroupDetails": UpdateManagedInstanceGroupDetails,
    "UpdateScheduledJobDetails": UpdateScheduledJobDetails,
    "UpdateSoftwareSourceDetails": UpdateSoftwareSourceDetails,
    "WindowsUpdate": WindowsUpdate,
    "WindowsUpdateSummary": WindowsUpdateSummary,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class JobLog(object):
    """
    Job log details. A job log is an audit log record inserted during the lifecycle of a job execution instance.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new JobLog object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this JobLog.
        :type key: str

        :param job_execution_key:
            The value to assign to the job_execution_key property of this JobLog.
        :type job_execution_key: str

        :param created_by_id:
            The value to assign to the created_by_id property of this JobLog.
        :type created_by_id: str

        :param updated_by_id:
            The value to assign to the updated_by_id property of this JobLog.
        :type updated_by_id: str

        :param time_updated:
            The value to assign to the time_updated property of this JobLog.
        :type time_updated: datetime

        :param time_created:
            The value to assign to the time_created property of this JobLog.
        :type time_created: datetime

        :param severity:
            The value to assign to the severity property of this JobLog.
        :type severity: str

        :param log_message:
            The value to assign to the log_message property of this JobLog.
        :type log_message: str

        :param uri:
            The value to assign to the uri property of this JobLog.
        :type uri: str

        """
        self.swagger_types = {
            'key': 'str',
            'job_execution_key': 'str',
            'created_by_id': 'str',
            'updated_by_id': 'str',
            'time_updated': 'datetime',
            'time_created': 'datetime',
            'severity': 'str',
            'log_message': 'str',
            'uri': 'str'
        }

        self.attribute_map = {
            'key': 'key',
            'job_execution_key': 'jobExecutionKey',
            'created_by_id': 'createdById',
            'updated_by_id': 'updatedById',
            'time_updated': 'timeUpdated',
            'time_created': 'timeCreated',
            'severity': 'severity',
            'log_message': 'logMessage',
            'uri': 'uri'
        }

        self._key = None
        self._job_execution_key = None
        self._created_by_id = None
        self._updated_by_id = None
        self._time_updated = None
        self._time_created = None
        self._severity = None
        self._log_message = None
        self._uri = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this JobLog.
        Unique key of the job log that is immutable.


        :return: The key of this JobLog.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this JobLog.
        Unique key of the job log that is immutable.


        :param key: The key of this JobLog.
        :type: str
        """
        self._key = key

    @property
    def job_execution_key(self):
        """
        Gets the job_execution_key of this JobLog.
        The unique key of the parent job execution for which the log resource was created.


        :return: The job_execution_key of this JobLog.
        :rtype: str
        """
        return self._job_execution_key

    @job_execution_key.setter
    def job_execution_key(self, job_execution_key):
        """
        Sets the job_execution_key of this JobLog.
        The unique key of the parent job execution for which the log resource was created.


        :param job_execution_key: The job_execution_key of this JobLog.
        :type: str
        """
        self._job_execution_key = job_execution_key

    @property
    def created_by_id(self):
        """
        Gets the created_by_id of this JobLog.
        OCID of the user who created the log record for this job. Usually the executor of the job instance.


        :return: The created_by_id of this JobLog.
        :rtype: str
        """
        return self._created_by_id

    @created_by_id.setter
    def created_by_id(self, created_by_id):
        """
        Sets the created_by_id of this JobLog.
        OCID of the user who created the log record for this job. Usually the executor of the job instance.


        :param created_by_id: The created_by_id of this JobLog.
        :type: str
        """
        self._created_by_id = created_by_id

    @property
    def updated_by_id(self):
        """
        Gets the updated_by_id of this JobLog.
        OCID of the user who created the log record for this job. Usually the executor of the job instance.


        :return: The updated_by_id of this JobLog.
        :rtype: str
        """
        return self._updated_by_id

    @updated_by_id.setter
    def updated_by_id(self, updated_by_id):
        """
        Sets the updated_by_id of this JobLog.
        OCID of the user who created the log record for this job. Usually the executor of the job instance.


        :param updated_by_id: The updated_by_id of this JobLog.
        :type: str
        """
        self._updated_by_id = updated_by_id

    @property
    def time_updated(self):
        """
        Gets the time_updated of this JobLog.
        Job log update time. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_updated of this JobLog.
        :rtype: datetime
        """
        return self._time_updated

    @time_updated.setter
    def time_updated(self, time_updated):
        """
        Sets the time_updated of this JobLog.
        Job log update time. An `RFC3339`__ formatted datetime string.

        __ https://tools.ietf.org/html/rfc3339


        :param time_updated: The time_updated of this JobLog.
        :type: datetime
        """
        self._time_updated = time_updated

    @property
    def time_created(self):
        """
        Gets the time_created of this JobLog.
        The date and time the job log was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :return: The time_created of this JobLog.
        :rtype: datetime
        """
        return self._time_created

    @time_created.setter
    def time_created(self, time_created):
        """
        Sets the time_created of this JobLog.
        The date and time the job log was created, in the format defined by `RFC3339`__.
        Example: `2019-03-25T21:10:29.600Z`

        __ https://tools.ietf.org/html/rfc3339


        :param time_created: The time_created of this JobLog.
        :type: datetime
        """
        self._time_created = time_created

    @property
    def severity(self):
        """
        Gets the severity of this JobLog.
        Severity level for this log.


        :return: The severity of this JobLog.
        :rtype: str
        """
        return self._severity

    @severity.setter
    def severity(self, severity):
        """
        Sets the severity of this JobLog.
        Severity level for this log.


        :param severity: The severity of this JobLog.
        :type: str
        """
        self._severity = severity

    @property
    def log_message(self):
        """
        Gets the log_message of this JobLog.
        Message for this job log.


        :return: The log_message of this JobLog.
        :rtype: str
        """
        return self._log_message

    @log_message.setter
    def log_message(self, log_message):
        """
        Sets the log_message of this JobLog.
        Message for this job log.


        :param log_message: The log_message of this JobLog.
        :type: str
        """
        self._log_message = log_message

    @property
    def uri(self):
        """
        Gets the uri of this JobLog.
        URI to the job log instance in the API.


        :return: The uri of this JobLog.
        :rtype: str
        """
        return self._uri

    @uri.setter
    def uri(self, uri):
        """
        Sets the uri of this JobLog.
        URI to the job log instance in the API.


        :param uri: The uri of this JobLog.
        :type: str
        """
        self._uri = uri

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class Span(object):
    """
    Definition of a span object.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new Span object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param key:
            The value to assign to the key property of this Span.
        :type key: str

        :param parent_span_key:
            The value to assign to the parent_span_key property of this Span.
        :type parent_span_key: str

        :param trace_key:
            The value to assign to the trace_key property of this Span.
        :type trace_key: str

        :param time_started:
            The value to assign to the time_started property of this Span.
        :type time_started: datetime

        :param time_ended:
            The value to assign to the time_ended property of this Span.
        :type time_ended: datetime

        :param duration_in_ms:
            The value to assign to the duration_in_ms property of this Span.
        :type duration_in_ms: int

        :param operation_name:
            The value to assign to the operation_name property of this Span.
        :type operation_name: str

        :param service_name:
            The value to assign to the service_name property of this Span.
        :type service_name: str

        :param kind:
            The value to assign to the kind property of this Span.
        :type kind: str

        :param tags:
            The value to assign to the tags property of this Span.
        :type tags: list[oci.apm_traces.models.Tag]

        :param logs:
            The value to assign to the logs property of this Span.
        :type logs: list[oci.apm_traces.models.SpanLogCollection]

        :param is_error:
            The value to assign to the is_error property of this Span.
        :type is_error: bool

        """
        self.swagger_types = {
            'key': 'str',
            'parent_span_key': 'str',
            'trace_key': 'str',
            'time_started': 'datetime',
            'time_ended': 'datetime',
            'duration_in_ms': 'int',
            'operation_name': 'str',
            'service_name': 'str',
            'kind': 'str',
            'tags': 'list[Tag]',
            'logs': 'list[SpanLogCollection]',
            'is_error': 'bool'
        }

        self.attribute_map = {
            'key': 'key',
            'parent_span_key': 'parentSpanKey',
            'trace_key': 'traceKey',
            'time_started': 'timeStarted',
            'time_ended': 'timeEnded',
            'duration_in_ms': 'durationInMs',
            'operation_name': 'operationName',
            'service_name': 'serviceName',
            'kind': 'kind',
            'tags': 'tags',
            'logs': 'logs',
            'is_error': 'isError'
        }

        self._key = None
        self._parent_span_key = None
        self._trace_key = None
        self._time_started = None
        self._time_ended = None
        self._duration_in_ms = None
        self._operation_name = None
        self._service_name = None
        self._kind = None
        self._tags = None
        self._logs = None
        self._is_error = None

    @property
    def key(self):
        """
        **[Required]** Gets the key of this Span.
        Unique identifier (spanId) for the span.  Note that this field is
        defined as spanKey in the API to comply with OCI API fields naming conventions.
        The spanKey maps to the spanId in the APM repository.


        :return: The key of this Span.
        :rtype: str
        """
        return self._key

    @key.setter
    def key(self, key):
        """
        Sets the key of this Span.
        Unique identifier (spanId) for the span.  Note that this field is
        defined as spanKey in the API to comply with OCI API fields naming conventions.
        The spanKey maps to the spanId in the APM repository.


        :param key: The key of this Span.
        :type: str
        """
        self._key = key

    @property
    def parent_span_key(self):
        """
        Gets the parent_span_key of this Span.
        Unique parent identifier for the span if one exists. For root spans this will be null.


        :return: The parent_span_key of this Span.
        :rtype: str
        """
        return self._parent_span_key

    @parent_span_key.setter
    def parent_span_key(self, parent_span_key):
        """
        Sets the parent_span_key of this Span.
        Unique parent identifier for the span if one exists. For root spans this will be null.


        :param parent_span_key: The parent_span_key of this Span.
        :type: str
        """
        self._parent_span_key = parent_span_key

    @property
    def trace_key(self):
        """
        **[Required]** Gets the trace_key of this Span.
        Unique identifier for the trace.


        :return: The trace_key of this Span.
        :rtype: str
        """
        return self._trace_key

    @trace_key.setter
    def trace_key(self, trace_key):
        """
        Sets the trace_key of this Span.
        Unique identifier for the trace.


        :param trace_key: The trace_key of this Span.
        :type: str
        """
        self._trace_key = trace_key

    @property
    def time_started(self):
        """
        **[Required]** Gets the time_started of this Span.
        Span start time.  Timestamp when the span was started.


        :return: The time_started of this Span.
        :rtype: datetime
        """
        return self._time_started

    @time_started.setter
    def time_started(self, time_started):
        """
        Sets the time_started of this Span.
        Span start time.  Timestamp when the span was started.


        :param time_started: The time_started of this Span.
        :type: datetime
        """
        self._time_started = time_started

    @property
    def time_ended(self):
        """
        **[Required]** Gets the time_ended of this Span.
        Span end time.  Timestamp when the span was completed.


        :return: The time_ended of this Span.
        :rtype: datetime
        """
        return self._time_ended

    @time_ended.setter
    def time_ended(self, time_ended):
        """
        Sets the time_ended of this Span.
        Span end time.  Timestamp when the span was completed.


        :param time_ended: The time_ended of this Span.
        :type: datetime
        """
        self._time_ended = time_ended

    @property
    def duration_in_ms(self):
        """
        **[Required]** Gets the duration_in_ms of this Span.
        Total span duration in milliseconds.


        :return: The duration_in_ms of this Span.
        :rtype: int
        """
        return self._duration_in_ms

    @duration_in_ms.setter
    def duration_in_ms(self, duration_in_ms):
        """
        Sets the duration_in_ms of this Span.
        Total span duration in milliseconds.


        :param duration_in_ms: The duration_in_ms of this Span.
        :type: int
        """
        self._duration_in_ms = duration_in_ms

    @property
    def operation_name(self):
        """
        **[Required]** Gets the operation_name of this Span.
        Span name associated with the trace.  This is usually the method or uri of the request.


        :return: The operation_name of this Span.
        :rtype: str
        """
        return self._operation_name

    @operation_name.setter
    def operation_name(self, operation_name):
        """
        Sets the operation_name of this Span.
        Span name associated with the trace.  This is usually the method or uri of the request.


        :param operation_name: The operation_name of this Span.
        :type: str
        """
        self._operation_name = operation_name

    @property
    def service_name(self):
        """
        Gets the service_name of this Span.
        Service name associated with the span.


        :return: The service_name of this Span.
        :rtype: str
        """
        return self._service_name

    @service_name.setter
    def service_name(self, service_name):
        """
        Sets the service_name of this Span.
        Service name associated with the span.


        :param service_name: The service_name of this Span.
        :type: str
        """
        self._service_name = service_name

    @property
    def kind(self):
        """
        Gets the kind of this Span.
        Kind associated with the span.


        :return: The kind of this Span.
        :rtype: str
        """
        return self._kind

    @kind.setter
    def kind(self, kind):
        """
        Sets the kind of this Span.
        Kind associated with the span.


        :param kind: The kind of this Span.
        :type: str
        """
        self._kind = kind

    @property
    def tags(self):
        """
        Gets the tags of this Span.
        List of tags associated with the span.


        :return: The tags of this Span.
        :rtype: list[oci.apm_traces.models.Tag]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """
        Sets the tags of this Span.
        List of tags associated with the span.


        :param tags: The tags of this Span.
        :type: list[oci.apm_traces.models.Tag]
        """
        self._tags = tags

    @property
    def logs(self):
        """
        Gets the logs of this Span.
        List of logs associated with the span.


        :return: The logs of this Span.
        :rtype: list[oci.apm_traces.models.SpanLogCollection]
        """
        return self._logs

    @logs.setter
    def logs(self, logs):
        """
        Sets the logs of this Span.
        List of logs associated with the span.


        :param logs: The logs of this Span.
        :type: list[oci.apm_traces.models.SpanLogCollection]
        """
        self._logs = logs

    @property
    def is_error(self):
        """
        **[Required]** Gets the is_error of this Span.
        Indicates if the span has an error


        :return: The is_error of this Span.
        :rtype: bool
        """
        return self._is_error

    @is_error.setter
    def is_error(self, is_error):
        """
        Sets the is_error of this Span.
        Indicates if the span has an error


        :param is_error: The is_error of this Span.
        :type: bool
        """
        self._is_error = is_error

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class InstanceConfigurationCreateVolumeDetails(object):
    """
    Creates a new block volume. Please see :class:`CreateVolumeDetails`
    """

    def __init__(self, **kwargs):
        """
        Initializes a new InstanceConfigurationCreateVolumeDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param availability_domain:
            The value to assign to the availability_domain property of this InstanceConfigurationCreateVolumeDetails.
        :type availability_domain: str

        :param backup_policy_id:
            The value to assign to the backup_policy_id property of this InstanceConfigurationCreateVolumeDetails.
        :type backup_policy_id: str

        :param compartment_id:
            The value to assign to the compartment_id property of this InstanceConfigurationCreateVolumeDetails.
        :type compartment_id: str

        :param defined_tags:
            The value to assign to the defined_tags property of this InstanceConfigurationCreateVolumeDetails.
        :type defined_tags: dict(str, dict(str, object))

        :param display_name:
            The value to assign to the display_name property of this InstanceConfigurationCreateVolumeDetails.
        :type display_name: str

        :param freeform_tags:
            The value to assign to the freeform_tags property of this InstanceConfigurationCreateVolumeDetails.
        :type freeform_tags: dict(str, str)

        :param kms_key_id:
            The value to assign to the kms_key_id property of this InstanceConfigurationCreateVolumeDetails.
        :type kms_key_id: str

        :param vpus_per_gb:
            The value to assign to the vpus_per_gb property of this InstanceConfigurationCreateVolumeDetails.
        :type vpus_per_gb: int

        :param size_in_gbs:
            The value to assign to the size_in_gbs property of this InstanceConfigurationCreateVolumeDetails.
        :type size_in_gbs: int

        :param source_details:
            The value to assign to the source_details property of this InstanceConfigurationCreateVolumeDetails.
        :type source_details: oci.core.models.InstanceConfigurationVolumeSourceDetails

        """
        self.swagger_types = {
            'availability_domain': 'str',
            'backup_policy_id': 'str',
            'compartment_id': 'str',
            'defined_tags': 'dict(str, dict(str, object))',
            'display_name': 'str',
            'freeform_tags': 'dict(str, str)',
            'kms_key_id': 'str',
            'vpus_per_gb': 'int',
            'size_in_gbs': 'int',
            'source_details': 'InstanceConfigurationVolumeSourceDetails'
        }

        self.attribute_map = {
            'availability_domain': 'availabilityDomain',
            'backup_policy_id': 'backupPolicyId',
            'compartment_id': 'compartmentId',
            'defined_tags': 'definedTags',
            'display_name': 'displayName',
            'freeform_tags': 'freeformTags',
            'kms_key_id': 'kmsKeyId',
            'vpus_per_gb': 'vpusPerGB',
            'size_in_gbs': 'sizeInGBs',
            'source_details': 'sourceDetails'
        }

        self._availability_domain = None
        self._backup_policy_id = None
        self._compartment_id = None
        self._defined_tags = None
        self._display_name = None
        self._freeform_tags = None
        self._kms_key_id = None
        self._vpus_per_gb = None
        self._size_in_gbs = None
        self._source_details = None

    @property
    def availability_domain(self):
        """
        Gets the availability_domain of this InstanceConfigurationCreateVolumeDetails.
        The availability domain of the volume.

        Example: `Uocm:PHX-AD-1`


        :return: The availability_domain of this InstanceConfigurationCreateVolumeDetails.
        :rtype: str
        """
        return self._availability_domain

    @availability_domain.setter
    def availability_domain(self, availability_domain):
        """
        Sets the availability_domain of this InstanceConfigurationCreateVolumeDetails.
        The availability domain of the volume.

        Example: `Uocm:PHX-AD-1`


        :param availability_domain: The availability_domain of this InstanceConfigurationCreateVolumeDetails.
        :type: str
        """
        self._availability_domain = availability_domain

    @property
    def backup_policy_id(self):
        """
        Gets the backup_policy_id of this InstanceConfigurationCreateVolumeDetails.
        If provided, specifies the ID of the volume backup policy to assign to the newly
        created volume. If omitted, no policy will be assigned.


        :return: The backup_policy_id of this InstanceConfigurationCreateVolumeDetails.
        :rtype: str
        """
        return self._backup_policy_id

    @backup_policy_id.setter
    def backup_policy_id(self, backup_policy_id):
        """
        Sets the backup_policy_id of this InstanceConfigurationCreateVolumeDetails.
        If provided, specifies the ID of the volume backup policy to assign to the newly
        created volume. If omitted, no policy will be assigned.


        :param backup_policy_id: The backup_policy_id of this InstanceConfigurationCreateVolumeDetails.
        :type: str
        """
        self._backup_policy_id = backup_policy_id

    @property
    def compartment_id(self):
        """
        Gets the compartment_id of this InstanceConfigurationCreateVolumeDetails.
        The OCID of the compartment that contains the volume.


        :return: The compartment_id of this InstanceConfigurationCreateVolumeDetails.
        :rtype: str
        """
        return self._compartment_id

    @compartment_id.setter
    def compartment_id(self, compartment_id):
        """
        Sets the compartment_id of this InstanceConfigurationCreateVolumeDetails.
        The OCID of the compartment that contains the volume.


        :param compartment_id: The compartment_id of this InstanceConfigurationCreateVolumeDetails.
        :type: str
        """
        self._compartment_id = compartment_id

    @property
    def defined_tags(self):
        """
        Gets the defined_tags of this InstanceConfigurationCreateVolumeDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The defined_tags of this InstanceConfigurationCreateVolumeDetails.
        :rtype: dict(str, dict(str, object))
        """
        return self._defined_tags

    @defined_tags.setter
    def defined_tags(self, defined_tags):
        """
        Sets the defined_tags of this InstanceConfigurationCreateVolumeDetails.
        Defined tags for this resource. Each key is predefined and scoped to a
        namespace. For more information, see `Resource Tags`__.

        Example: `{\"Operations\": {\"CostCenter\": \"42\"}}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param defined_tags: The defined_tags of this InstanceConfigurationCreateVolumeDetails.
        :type: dict(str, dict(str, object))
        """
        self._defined_tags = defined_tags

    @property
    def display_name(self):
        """
        Gets the display_name of this InstanceConfigurationCreateVolumeDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :return: The display_name of this InstanceConfigurationCreateVolumeDetails.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this InstanceConfigurationCreateVolumeDetails.
        A user-friendly name. Does not have to be unique, and it's changeable.
        Avoid entering confidential information.


        :param display_name: The display_name of this InstanceConfigurationCreateVolumeDetails.
        :type: str
        """
        self._display_name = display_name

    @property
    def freeform_tags(self):
        """
        Gets the freeform_tags of this InstanceConfigurationCreateVolumeDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :return: The freeform_tags of this InstanceConfigurationCreateVolumeDetails.
        :rtype: dict(str, str)
        """
        return self._freeform_tags

    @freeform_tags.setter
    def freeform_tags(self, freeform_tags):
        """
        Sets the freeform_tags of this InstanceConfigurationCreateVolumeDetails.
        Free-form tags for this resource. Each tag is a simple key-value pair with no
        predefined name, type, or namespace. For more information, see `Resource Tags`__.

        Example: `{\"Department\": \"Finance\"}`

        __ https://docs.cloud.oracle.com/iaas/Content/General/Concepts/resourcetags.htm


        :param freeform_tags: The freeform_tags of this InstanceConfigurationCreateVolumeDetails.
        :type: dict(str, str)
        """
        self._freeform_tags = freeform_tags

    @property
    def kms_key_id(self):
        """
        Gets the kms_key_id of this InstanceConfigurationCreateVolumeDetails.
        The OCID of the Key Management key to assign as the master encryption key
        for the volume.


        :return: The kms_key_id of this InstanceConfigurationCreateVolumeDetails.
        :rtype: str
        """
        return self._kms_key_id

    @kms_key_id.setter
    def kms_key_id(self, kms_key_id):
        """
        Sets the kms_key_id of this InstanceConfigurationCreateVolumeDetails.
        The OCID of the Key Management key to assign as the master encryption key
        for the volume.


        :param kms_key_id: The kms_key_id of this InstanceConfigurationCreateVolumeDetails.
        :type: str
        """
        self._kms_key_id = kms_key_id

    @property
    def vpus_per_gb(self):
        """
        Gets the vpus_per_gb of this InstanceConfigurationCreateVolumeDetails.
        The number of volume performance units (VPUs) that will be applied to this volume per GB,
        representing the Block Volume service's elastic performance options.
        See `Block Volume Elastic Performance`__ for more information.

        Allowed values:

          * `0`: Represents Lower Cost option.

          * `10`: Represents Balanced option.

          * `20`: Represents Higher Performance option.

        __ https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumeelasticperformance.htm


        :return: The vpus_per_gb of this InstanceConfigurationCreateVolumeDetails.
        :rtype: int
        """
        return self._vpus_per_gb

    @vpus_per_gb.setter
    def vpus_per_gb(self, vpus_per_gb):
        """
        Sets the vpus_per_gb of this InstanceConfigurationCreateVolumeDetails.
        The number of volume performance units (VPUs) that will be applied to this volume per GB,
        representing the Block Volume service's elastic performance options.
        See `Block Volume Elastic Performance`__ for more information.

        Allowed values:

          * `0`: Represents Lower Cost option.

          * `10`: Represents Balanced option.

          * `20`: Represents Higher Performance option.

        __ https://docs.cloud.oracle.com/iaas/Content/Block/Concepts/blockvolumeelasticperformance.htm


        :param vpus_per_gb: The vpus_per_gb of this InstanceConfigurationCreateVolumeDetails.
        :type: int
        """
        self._vpus_per_gb = vpus_per_gb

    @property
    def size_in_gbs(self):
        """
        Gets the size_in_gbs of this InstanceConfigurationCreateVolumeDetails.
        The size of the volume in GBs.


        :return: The size_in_gbs of this InstanceConfigurationCreateVolumeDetails.
        :rtype: int
        """
        return self._size_in_gbs

    @size_in_gbs.setter
    def size_in_gbs(self, size_in_gbs):
        """
        Sets the size_in_gbs of this InstanceConfigurationCreateVolumeDetails.
        The size of the volume in GBs.


        :param size_in_gbs: The size_in_gbs of this InstanceConfigurationCreateVolumeDetails.
        :type: int
        """
        self._size_in_gbs = size_in_gbs

    @property
    def source_details(self):
        """
        Gets the source_details of this InstanceConfigurationCreateVolumeDetails.

        :return: The source_details of this InstanceConfigurationCreateVolumeDetails.
        :rtype: oci.core.models.InstanceConfigurationVolumeSourceDetails
        """
        return self._source_details

    @source_details.setter
    def source_details(self, source_details):
        """
        Sets the source_details of this InstanceConfigurationCreateVolumeDetails.

        :param source_details: The source_details of this InstanceConfigurationCreateVolumeDetails.
        :type: oci.core.models.InstanceConfigurationVolumeSourceDetails
        """
        self._source_details = source_details

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ZoneTransferServer(object):
    """
    An OCI nameserver that transfers zone data with external nameservers.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new ZoneTransferServer object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param address:
            The value to assign to the address property of this ZoneTransferServer.
        :type address: str

        :param port:
            The value to assign to the port property of this ZoneTransferServer.
        :type port: int

        :param is_transfer_source:
            The value to assign to the is_transfer_source property of this ZoneTransferServer.
        :type is_transfer_source: bool

        :param is_transfer_destination:
            The value to assign to the is_transfer_destination property of this ZoneTransferServer.
        :type is_transfer_destination: bool

        """
        self.swagger_types = {
            'address': 'str',
            'port': 'int',
            'is_transfer_source': 'bool',
            'is_transfer_destination': 'bool'
        }

        self.attribute_map = {
            'address': 'address',
            'port': 'port',
            'is_transfer_source': 'isTransferSource',
            'is_transfer_destination': 'isTransferDestination'
        }

        self._address = None
        self._port = None
        self._is_transfer_source = None
        self._is_transfer_destination = None

    @property
    def address(self):
        """
        **[Required]** Gets the address of this ZoneTransferServer.
        The server's IP address (IPv4 or IPv6).


        :return: The address of this ZoneTransferServer.
        :rtype: str
        """
        return self._address

    @address.setter
    def address(self, address):
        """
        Sets the address of this ZoneTransferServer.
        The server's IP address (IPv4 or IPv6).


        :param address: The address of this ZoneTransferServer.
        :type: str
        """
        self._address = address

    @property
    def port(self):
        """
        Gets the port of this ZoneTransferServer.
        The server's port.


        :return: The port of this ZoneTransferServer.
        :rtype: int
        """
        return self._port

    @port.setter
    def port(self, port):
        """
        Sets the port of this ZoneTransferServer.
        The server's port.


        :param port: The port of this ZoneTransferServer.
        :type: int
        """
        self._port = port

    @property
    def is_transfer_source(self):
        """
        Gets the is_transfer_source of this ZoneTransferServer.
        A Boolean flag indicating whether or not the server is a zone data transfer source.


        :return: The is_transfer_source of this ZoneTransferServer.
        :rtype: bool
        """
        return self._is_transfer_source

    @is_transfer_source.setter
    def is_transfer_source(self, is_transfer_source):
        """
        Sets the is_transfer_source of this ZoneTransferServer.
        A Boolean flag indicating whether or not the server is a zone data transfer source.


        :param is_transfer_source: The is_transfer_source of this ZoneTransferServer.
        :type: bool
        """
        self._is_transfer_source = is_transfer_source

    @property
    def is_transfer_destination(self):
        """
        Gets the is_transfer_destination of this ZoneTransferServer.
        A Boolean flag indicating whether or not the server is a zone data transfer destination.


        :return: The is_transfer_destination of this ZoneTransferServer.
        :rtype: bool
        """
        return self._is_transfer_destination

    @is_transfer_destination.setter
    def is_transfer_destination(self, is_transfer_destination):
        """
        Sets the is_transfer_destination of this ZoneTransferServer.
        A Boolean flag indicating whether or not the server is a zone data transfer destination.


        :param is_transfer_destination: The is_transfer_destination of this ZoneTransferServer.
        :type: bool
        """
        self._is_transfer_destination = is_transfer_destination

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .change_rover_cluster_compartment_details import ChangeRoverClusterCompartmentDetails
from .change_rover_entitlement_compartment_details import ChangeRoverEntitlementCompartmentDetails
from .change_rover_node_compartment_details import ChangeRoverNodeCompartmentDetails
from .create_rover_cluster_details import CreateRoverClusterDetails
from .create_rover_entitlement_details import CreateRoverEntitlementDetails
from .create_rover_node_details import CreateRoverNodeDetails
from .rover_cluster import RoverCluster
from .rover_cluster_certificate import RoverClusterCertificate
from .rover_cluster_collection import RoverClusterCollection
from .rover_cluster_summary import RoverClusterSummary
from .rover_entitlement import RoverEntitlement
from .rover_entitlement_collection import RoverEntitlementCollection
from .rover_entitlement_summary import RoverEntitlementSummary
from .rover_node import RoverNode
from .rover_node_action_set_key_details import RoverNodeActionSetKeyDetails
from .rover_node_certificate import RoverNodeCertificate
from .rover_node_collection import RoverNodeCollection
from .rover_node_encryption_key import RoverNodeEncryptionKey
from .rover_node_get_rpt import RoverNodeGetRpt
from .rover_node_set_key import RoverNodeSetKey
from .rover_node_summary import RoverNodeSummary
from .rover_workload import RoverWorkload
from .shipping_address import ShippingAddress
from .update_rover_cluster_details import UpdateRoverClusterDetails
from .update_rover_entitlement_details import UpdateRoverEntitlementDetails
from .update_rover_node_details import UpdateRoverNodeDetails

# Maps type names to classes for rover services.
rover_type_mapping = {
    "ChangeRoverClusterCompartmentDetails": ChangeRoverClusterCompartmentDetails,
    "ChangeRoverEntitlementCompartmentDetails": ChangeRoverEntitlementCompartmentDetails,
    "ChangeRoverNodeCompartmentDetails": ChangeRoverNodeCompartmentDetails,
    "CreateRoverClusterDetails": CreateRoverClusterDetails,
    "CreateRoverEntitlementDetails": CreateRoverEntitlementDetails,
    "CreateRoverNodeDetails": CreateRoverNodeDetails,
    "RoverCluster": RoverCluster,
    "RoverClusterCertificate": RoverClusterCertificate,
    "RoverClusterCollection": RoverClusterCollection,
    "RoverClusterSummary": RoverClusterSummary,
    "RoverEntitlement": RoverEntitlement,
    "RoverEntitlementCollection": RoverEntitlementCollection,
    "RoverEntitlementSummary": RoverEntitlementSummary,
    "RoverNode": RoverNode,
    "RoverNodeActionSetKeyDetails": RoverNodeActionSetKeyDetails,
    "RoverNodeCertificate": RoverNodeCertificate,
    "RoverNodeCollection": RoverNodeCollection,
    "RoverNodeEncryptionKey": RoverNodeEncryptionKey,
    "RoverNodeGetRpt": RoverNodeGetRpt,
    "RoverNodeSetKey": RoverNodeSetKey,
    "RoverNodeSummary": RoverNodeSummary,
    "RoverWorkload": RoverWorkload,
    "ShippingAddress": ShippingAddress,
    "UpdateRoverClusterDetails": UpdateRoverClusterDetails,
    "UpdateRoverEntitlementDetails": UpdateRoverEntitlementDetails,
    "UpdateRoverNodeDetails": UpdateRoverNodeDetails
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .create_job_operation_details import CreateJobOperationDetails
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class CreateDestroyJobOperationDetails(CreateJobOperationDetails):
    """
    Job details that are specific to destroy operations.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new CreateDestroyJobOperationDetails object with values from keyword arguments. The default value of the :py:attr:`~oci.resource_manager.models.CreateDestroyJobOperationDetails.operation` attribute
        of this class is ``DESTROY`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param operation:
            The value to assign to the operation property of this CreateDestroyJobOperationDetails.
        :type operation: str

        :param terraform_advanced_options:
            The value to assign to the terraform_advanced_options property of this CreateDestroyJobOperationDetails.
        :type terraform_advanced_options: oci.resource_manager.models.TerraformAdvancedOptions

        :param execution_plan_strategy:
            The value to assign to the execution_plan_strategy property of this CreateDestroyJobOperationDetails.
        :type execution_plan_strategy: str

        """
        self.swagger_types = {
            'operation': 'str',
            'terraform_advanced_options': 'TerraformAdvancedOptions',
            'execution_plan_strategy': 'str'
        }

        self.attribute_map = {
            'operation': 'operation',
            'terraform_advanced_options': 'terraformAdvancedOptions',
            'execution_plan_strategy': 'executionPlanStrategy'
        }

        self._operation = None
        self._terraform_advanced_options = None
        self._execution_plan_strategy = None
        self._operation = 'DESTROY'

    @property
    def terraform_advanced_options(self):
        """
        Gets the terraform_advanced_options of this CreateDestroyJobOperationDetails.

        :return: The terraform_advanced_options of this CreateDestroyJobOperationDetails.
        :rtype: oci.resource_manager.models.TerraformAdvancedOptions
        """
        return self._terraform_advanced_options

    @terraform_advanced_options.setter
    def terraform_advanced_options(self, terraform_advanced_options):
        """
        Sets the terraform_advanced_options of this CreateDestroyJobOperationDetails.

        :param terraform_advanced_options: The terraform_advanced_options of this CreateDestroyJobOperationDetails.
        :type: oci.resource_manager.models.TerraformAdvancedOptions
        """
        self._terraform_advanced_options = terraform_advanced_options

    @property
    def execution_plan_strategy(self):
        """
        **[Required]** Gets the execution_plan_strategy of this CreateDestroyJobOperationDetails.
        Specifies the source of the execution plan to apply.
        Currently, only `AUTO_APPROVED` is allowed, which indicates that the job
        will be run without an execution plan.


        :return: The execution_plan_strategy of this CreateDestroyJobOperationDetails.
        :rtype: str
        """
        return self._execution_plan_strategy

    @execution_plan_strategy.setter
    def execution_plan_strategy(self, execution_plan_strategy):
        """
        Sets the execution_plan_strategy of this CreateDestroyJobOperationDetails.
        Specifies the source of the execution plan to apply.
        Currently, only `AUTO_APPROVED` is allowed, which indicates that the job
        will be run without an execution plan.


        :param execution_plan_strategy: The execution_plan_strategy of this CreateDestroyJobOperationDetails.
        :type: str
        """
        self._execution_plan_strategy = execution_plan_strategy

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Modified Work: Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.
# Copyright 2008-2016 Andrey Petrov and contributors

import collections

from ..packages import six
from ..packages.six.moves import queue

if six.PY2:
    # Queue is imported for side effects on MS Windows. See issue #229.
    import Queue as _unused_module_Queue  # noqa: F401


class LifoQueue(queue.Queue):
    def _init(self, _):
        self.queue = collections.deque()

    def _qsize(self, len=len):
        return len(self.queue)

    def _put(self, item):
        self.queue.append(item)

    def _get(self):
        return self.queue.pop()



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class UpdateTargetResponderRuleDetails(object):
    """
    Details of ResponderRule.
    """

    #: A constant which can be used with the mode property of a UpdateTargetResponderRuleDetails.
    #: This constant has a value of "AUTOACTION"
    MODE_AUTOACTION = "AUTOACTION"

    #: A constant which can be used with the mode property of a UpdateTargetResponderRuleDetails.
    #: This constant has a value of "USERACTION"
    MODE_USERACTION = "USERACTION"

    def __init__(self, **kwargs):
        """
        Initializes a new UpdateTargetResponderRuleDetails object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param condition:
            The value to assign to the condition property of this UpdateTargetResponderRuleDetails.
        :type condition: oci.cloud_guard.models.Condition

        :param configurations:
            The value to assign to the configurations property of this UpdateTargetResponderRuleDetails.
        :type configurations: list[oci.cloud_guard.models.ResponderConfiguration]

        :param mode:
            The value to assign to the mode property of this UpdateTargetResponderRuleDetails.
            Allowed values for this property are: "AUTOACTION", "USERACTION"
        :type mode: str

        """
        self.swagger_types = {
            'condition': 'Condition',
            'configurations': 'list[ResponderConfiguration]',
            'mode': 'str'
        }

        self.attribute_map = {
            'condition': 'condition',
            'configurations': 'configurations',
            'mode': 'mode'
        }

        self._condition = None
        self._configurations = None
        self._mode = None

    @property
    def condition(self):
        """
        Gets the condition of this UpdateTargetResponderRuleDetails.

        :return: The condition of this UpdateTargetResponderRuleDetails.
        :rtype: oci.cloud_guard.models.Condition
        """
        return self._condition

    @condition.setter
    def condition(self, condition):
        """
        Sets the condition of this UpdateTargetResponderRuleDetails.

        :param condition: The condition of this UpdateTargetResponderRuleDetails.
        :type: oci.cloud_guard.models.Condition
        """
        self._condition = condition

    @property
    def configurations(self):
        """
        Gets the configurations of this UpdateTargetResponderRuleDetails.
        Configurations associated with the ResponderRule


        :return: The configurations of this UpdateTargetResponderRuleDetails.
        :rtype: list[oci.cloud_guard.models.ResponderConfiguration]
        """
        return self._configurations

    @configurations.setter
    def configurations(self, configurations):
        """
        Sets the configurations of this UpdateTargetResponderRuleDetails.
        Configurations associated with the ResponderRule


        :param configurations: The configurations of this UpdateTargetResponderRuleDetails.
        :type: list[oci.cloud_guard.models.ResponderConfiguration]
        """
        self._configurations = configurations

    @property
    def mode(self):
        """
        Gets the mode of this UpdateTargetResponderRuleDetails.
        Execution Mode for ResponderRule

        Allowed values for this property are: "AUTOACTION", "USERACTION"


        :return: The mode of this UpdateTargetResponderRuleDetails.
        :rtype: str
        """
        return self._mode

    @mode.setter
    def mode(self, mode):
        """
        Sets the mode of this UpdateTargetResponderRuleDetails.
        Execution Mode for ResponderRule


        :param mode: The mode of this UpdateTargetResponderRuleDetails.
        :type: str
        """
        allowed_values = ["AUTOACTION", "USERACTION"]
        if not value_allowed_none_or_none_sentinel(mode, allowed_values):
            raise ValueError(
                "Invalid value for `mode`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._mode = mode

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import

from .access_rule import AccessRule
from .access_rule_criteria import AccessRuleCriteria
from .add_http_response_header_action import AddHttpResponseHeaderAction
from .address_list import AddressList
from .address_list_summary import AddressListSummary
from .address_rate_limiting import AddressRateLimiting
from .block_challenge_settings import BlockChallengeSettings
from .caching_rule import CachingRule
from .caching_rule_criteria import CachingRuleCriteria
from .caching_rule_summary import CachingRuleSummary
from .captcha import Captcha
from .certificate import Certificate
from .certificate_extensions import CertificateExtensions
from .certificate_issuer_name import CertificateIssuerName
from .certificate_public_key_info import CertificatePublicKeyInfo
from .certificate_subject_name import CertificateSubjectName
from .certificate_summary import CertificateSummary
from .change_address_list_compartment_details import ChangeAddressListCompartmentDetails
from .change_certificate_compartment_details import ChangeCertificateCompartmentDetails
from .change_custom_protection_rule_compartment_details import ChangeCustomProtectionRuleCompartmentDetails
from .change_http_redirect_compartment_details import ChangeHttpRedirectCompartmentDetails
from .change_waas_policy_compartment_details import ChangeWaasPolicyCompartmentDetails
from .create_address_list_details import CreateAddressListDetails
from .create_certificate_details import CreateCertificateDetails
from .create_custom_protection_rule_details import CreateCustomProtectionRuleDetails
from .create_http_redirect_details import CreateHttpRedirectDetails
from .create_waas_policy_details import CreateWaasPolicyDetails
from .custom_protection_rule import CustomProtectionRule
from .custom_protection_rule_setting import CustomProtectionRuleSetting
from .custom_protection_rule_summary import CustomProtectionRuleSummary
from .device_fingerprint_challenge import DeviceFingerprintChallenge
from .edge_subnet import EdgeSubnet
from .extend_http_response_header_action import ExtendHttpResponseHeaderAction
from .good_bot import GoodBot
from .header import Header
from .header_manipulation_action import HeaderManipulationAction
from .health_check import HealthCheck
from .http_redirect import HttpRedirect
from .http_redirect_summary import HttpRedirectSummary
from .http_redirect_target import HttpRedirectTarget
from .human_interaction_challenge import HumanInteractionChallenge
from .ip_hash_load_balancing_method import IPHashLoadBalancingMethod
from .js_challenge import JsChallenge
from .load_balancing_method import LoadBalancingMethod
from .origin import Origin
from .origin_group import OriginGroup
from .origin_group_origins import OriginGroupOrigins
from .policy_config import PolicyConfig
from .protection_rule import ProtectionRule
from .protection_rule_action import ProtectionRuleAction
from .protection_rule_exclusion import ProtectionRuleExclusion
from .protection_settings import ProtectionSettings
from .purge_cache import PurgeCache
from .recommendation import Recommendation
from .remove_http_response_header_action import RemoveHttpResponseHeaderAction
from .round_robin_load_balancing_method import RoundRobinLoadBalancingMethod
from .sticky_cookie_load_balancing_method import StickyCookieLoadBalancingMethod
from .threat_feed import ThreatFeed
from .threat_feed_action import ThreatFeedAction
from .update_address_list_details import UpdateAddressListDetails
from .update_certificate_details import UpdateCertificateDetails
from .update_custom_protection_rule_details import UpdateCustomProtectionRuleDetails
from .update_http_redirect_details import UpdateHttpRedirectDetails
from .update_waas_policy_details import UpdateWaasPolicyDetails
from .waas_policy import WaasPolicy
from .waas_policy_custom_protection_rule_summary import WaasPolicyCustomProtectionRuleSummary
from .waas_policy_summary import WaasPolicySummary
from .waf_blocked_request import WafBlockedRequest
from .waf_config import WafConfig
from .waf_config_details import WafConfigDetails
from .waf_log import WafLog
from .waf_meter_datum import WafMeterDatum
from .waf_request import WafRequest
from .waf_traffic_datum import WafTrafficDatum
from .whitelist import Whitelist
from .work_request import WorkRequest
from .work_request_error import WorkRequestError
from .work_request_log_entry import WorkRequestLogEntry
from .work_request_resource import WorkRequestResource
from .work_request_summary import WorkRequestSummary

# Maps type names to classes for waas services.
waas_type_mapping = {
    "AccessRule": AccessRule,
    "AccessRuleCriteria": AccessRuleCriteria,
    "AddHttpResponseHeaderAction": AddHttpResponseHeaderAction,
    "AddressList": AddressList,
    "AddressListSummary": AddressListSummary,
    "AddressRateLimiting": AddressRateLimiting,
    "BlockChallengeSettings": BlockChallengeSettings,
    "CachingRule": CachingRule,
    "CachingRuleCriteria": CachingRuleCriteria,
    "CachingRuleSummary": CachingRuleSummary,
    "Captcha": Captcha,
    "Certificate": Certificate,
    "CertificateExtensions": CertificateExtensions,
    "CertificateIssuerName": CertificateIssuerName,
    "CertificatePublicKeyInfo": CertificatePublicKeyInfo,
    "CertificateSubjectName": CertificateSubjectName,
    "CertificateSummary": CertificateSummary,
    "ChangeAddressListCompartmentDetails": ChangeAddressListCompartmentDetails,
    "ChangeCertificateCompartmentDetails": ChangeCertificateCompartmentDetails,
    "ChangeCustomProtectionRuleCompartmentDetails": ChangeCustomProtectionRuleCompartmentDetails,
    "ChangeHttpRedirectCompartmentDetails": ChangeHttpRedirectCompartmentDetails,
    "ChangeWaasPolicyCompartmentDetails": ChangeWaasPolicyCompartmentDetails,
    "CreateAddressListDetails": CreateAddressListDetails,
    "CreateCertificateDetails": CreateCertificateDetails,
    "CreateCustomProtectionRuleDetails": CreateCustomProtectionRuleDetails,
    "CreateHttpRedirectDetails": CreateHttpRedirectDetails,
    "CreateWaasPolicyDetails": CreateWaasPolicyDetails,
    "CustomProtectionRule": CustomProtectionRule,
    "CustomProtectionRuleSetting": CustomProtectionRuleSetting,
    "CustomProtectionRuleSummary": CustomProtectionRuleSummary,
    "DeviceFingerprintChallenge": DeviceFingerprintChallenge,
    "EdgeSubnet": EdgeSubnet,
    "ExtendHttpResponseHeaderAction": ExtendHttpResponseHeaderAction,
    "GoodBot": GoodBot,
    "Header": Header,
    "HeaderManipulationAction": HeaderManipulationAction,
    "HealthCheck": HealthCheck,
    "HttpRedirect": HttpRedirect,
    "HttpRedirectSummary": HttpRedirectSummary,
    "HttpRedirectTarget": HttpRedirectTarget,
    "HumanInteractionChallenge": HumanInteractionChallenge,
    "IPHashLoadBalancingMethod": IPHashLoadBalancingMethod,
    "JsChallenge": JsChallenge,
    "LoadBalancingMethod": LoadBalancingMethod,
    "Origin": Origin,
    "OriginGroup": OriginGroup,
    "OriginGroupOrigins": OriginGroupOrigins,
    "PolicyConfig": PolicyConfig,
    "ProtectionRule": ProtectionRule,
    "ProtectionRuleAction": ProtectionRuleAction,
    "ProtectionRuleExclusion": ProtectionRuleExclusion,
    "ProtectionSettings": ProtectionSettings,
    "PurgeCache": PurgeCache,
    "Recommendation": Recommendation,
    "RemoveHttpResponseHeaderAction": RemoveHttpResponseHeaderAction,
    "RoundRobinLoadBalancingMethod": RoundRobinLoadBalancingMethod,
    "StickyCookieLoadBalancingMethod": StickyCookieLoadBalancingMethod,
    "ThreatFeed": ThreatFeed,
    "ThreatFeedAction": ThreatFeedAction,
    "UpdateAddressListDetails": UpdateAddressListDetails,
    "UpdateCertificateDetails": UpdateCertificateDetails,
    "UpdateCustomProtectionRuleDetails": UpdateCustomProtectionRuleDetails,
    "UpdateHttpRedirectDetails": UpdateHttpRedirectDetails,
    "UpdateWaasPolicyDetails": UpdateWaasPolicyDetails,
    "WaasPolicy": WaasPolicy,
    "WaasPolicyCustomProtectionRuleSummary": WaasPolicyCustomProtectionRuleSummary,
    "WaasPolicySummary": WaasPolicySummary,
    "WafBlockedRequest": WafBlockedRequest,
    "WafConfig": WafConfig,
    "WafConfigDetails": WafConfigDetails,
    "WafLog": WafLog,
    "WafMeterDatum": WafMeterDatum,
    "WafRequest": WafRequest,
    "WafTrafficDatum": WafTrafficDatum,
    "Whitelist": Whitelist,
    "WorkRequest": WorkRequest,
    "WorkRequestError": WorkRequestError,
    "WorkRequestLogEntry": WorkRequestLogEntry,
    "WorkRequestResource": WorkRequestResource,
    "WorkRequestSummary": WorkRequestSummary
}



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

import oci  # noqa: F401
from oci.util import WAIT_RESOURCE_NOT_FOUND  # noqa: F401


class DataSafeClientCompositeOperations(object):
    """
    This class provides a wrapper around :py:class:`~oci.data_safe.DataSafeClient` and offers convenience methods
    for operations that would otherwise need to be chained together. For example, instead of performing an action
    on a resource (e.g. launching an instance, creating a load balancer) and then using a waiter to wait for the resource
    to enter a given state, you can call a single method in this class to accomplish the same functionality
    """

    def __init__(self, client, **kwargs):
        """
        Creates a new DataSafeClientCompositeOperations object

        :param DataSafeClient client:
            The service client which will be wrapped by this object
        """
        self.client = client

    def activate_target_database_and_wait_for_state(self, activate_target_database_details, target_database_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.activate_target_database` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param oci.data_safe.models.ActivateTargetDatabaseDetails activate_target_database_details: (required)
            The details used to reactivate a target database in Data Safe.

        :param str target_database_id: (required)
            The OCID of the Data Safe target database.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.activate_target_database`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.activate_target_database(activate_target_database_details, target_database_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def change_data_safe_private_endpoint_compartment_and_wait_for_state(self, data_safe_private_endpoint_id, change_data_safe_private_endpoint_compartment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.change_data_safe_private_endpoint_compartment` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str data_safe_private_endpoint_id: (required)
            The OCID of the private endpoint.

        :param oci.data_safe.models.ChangeDataSafePrivateEndpointCompartmentDetails change_data_safe_private_endpoint_compartment_details: (required)
            The details used to change the compartment of a Data Safe private endpoint.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.change_data_safe_private_endpoint_compartment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.change_data_safe_private_endpoint_compartment(data_safe_private_endpoint_id, change_data_safe_private_endpoint_compartment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def compare_security_assessment_and_wait_for_state(self, security_assessment_id, compare_security_assessment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.compare_security_assessment` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str security_assessment_id: (required)
            The OCID of the security assessment.

        :param oci.data_safe.models.CompareSecurityAssessmentDetails compare_security_assessment_details: (required)
            Details of the security assessment comparison.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.compare_security_assessment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.compare_security_assessment(security_assessment_id, compare_security_assessment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def compare_user_assessment_and_wait_for_state(self, user_assessment_id, compare_user_assessment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.compare_user_assessment` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str user_assessment_id: (required)
            The OCID of the user assessment.

        :param oci.data_safe.models.CompareUserAssessmentDetails compare_user_assessment_details: (required)
            Details of the user assessment comparison.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.compare_user_assessment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.compare_user_assessment(user_assessment_id, compare_user_assessment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_data_safe_private_endpoint_and_wait_for_state(self, create_data_safe_private_endpoint_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.create_data_safe_private_endpoint` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param oci.data_safe.models.CreateDataSafePrivateEndpointDetails create_data_safe_private_endpoint_details: (required)
            Details to create a new private endpoint.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.create_data_safe_private_endpoint`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_data_safe_private_endpoint(create_data_safe_private_endpoint_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_on_prem_connector_and_wait_for_state(self, create_on_prem_connector_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.create_on_prem_connector` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param oci.data_safe.models.CreateOnPremConnectorDetails create_on_prem_connector_details: (required)
            The details used to create a new on-premises connector.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.create_on_prem_connector`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_on_prem_connector(create_on_prem_connector_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_security_assessment_and_wait_for_state(self, create_security_assessment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.create_security_assessment` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param oci.data_safe.models.CreateSecurityAssessmentDetails create_security_assessment_details: (required)
            The details used to create a new saved security assessment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.create_security_assessment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_security_assessment(create_security_assessment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_target_database_and_wait_for_state(self, create_target_database_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.create_target_database` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param oci.data_safe.models.CreateTargetDatabaseDetails create_target_database_details: (required)
            Details of the target database.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.create_target_database`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_target_database(create_target_database_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def create_user_assessment_and_wait_for_state(self, create_user_assessment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.create_user_assessment` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param oci.data_safe.models.CreateUserAssessmentDetails create_user_assessment_details: (required)
            The details used to create a new saved user assessment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.create_user_assessment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.create_user_assessment(create_user_assessment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def deactivate_target_database_and_wait_for_state(self, target_database_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.deactivate_target_database` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str target_database_id: (required)
            The OCID of the Data Safe target database.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.deactivate_target_database`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.deactivate_target_database(target_database_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_data_safe_private_endpoint_and_wait_for_state(self, data_safe_private_endpoint_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.delete_data_safe_private_endpoint` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str data_safe_private_endpoint_id: (required)
            The OCID of the private endpoint.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.delete_data_safe_private_endpoint`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_data_safe_private_endpoint(data_safe_private_endpoint_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_on_prem_connector_and_wait_for_state(self, on_prem_connector_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.delete_on_prem_connector` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str on_prem_connector_id: (required)
            The OCID of the on-premises connector.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.delete_on_prem_connector`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_on_prem_connector(on_prem_connector_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_security_assessment_and_wait_for_state(self, security_assessment_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.delete_security_assessment` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str security_assessment_id: (required)
            The OCID of the security assessment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.delete_security_assessment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_security_assessment(security_assessment_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_target_database_and_wait_for_state(self, target_database_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.delete_target_database` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str target_database_id: (required)
            The OCID of the Data Safe target database.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.delete_target_database`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_target_database(target_database_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def delete_user_assessment_and_wait_for_state(self, user_assessment_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.delete_user_assessment` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str user_assessment_id: (required)
            The OCID of the user assessment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.delete_user_assessment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = None
        try:
            operation_result = self.client.delete_user_assessment(user_assessment_id, **operation_kwargs)
        except oci.exceptions.ServiceError as e:
            if e.status == 404:
                return WAIT_RESOURCE_NOT_FOUND
            else:
                raise e

        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def enable_data_safe_configuration_and_wait_for_state(self, enable_data_safe_configuration_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.enable_data_safe_configuration` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param oci.data_safe.models.EnableDataSafeConfigurationDetails enable_data_safe_configuration_details: (required)
            The details used to enable Data Safe.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.enable_data_safe_configuration`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.enable_data_safe_configuration(enable_data_safe_configuration_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def generate_security_assessment_report_and_wait_for_state(self, security_assessment_id, generate_security_assessment_report_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.generate_security_assessment_report` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str security_assessment_id: (required)
            The OCID of the security assessment.

        :param oci.data_safe.models.GenerateSecurityAssessmentReportDetails generate_security_assessment_report_details: (required)
            Details of the report.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.generate_security_assessment_report`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.generate_security_assessment_report(security_assessment_id, generate_security_assessment_report_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def generate_user_assessment_report_and_wait_for_state(self, user_assessment_id, generate_user_assessment_report_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.generate_user_assessment_report` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str user_assessment_id: (required)
            The OCID of the user assessment.

        :param oci.data_safe.models.GenerateUserAssessmentReportDetails generate_user_assessment_report_details: (required)
            Details of the report.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.generate_user_assessment_report`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.generate_user_assessment_report(user_assessment_id, generate_user_assessment_report_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def refresh_security_assessment_and_wait_for_state(self, security_assessment_id, run_security_assessment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.refresh_security_assessment` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str security_assessment_id: (required)
            The OCID of the security assessment.

        :param oci.data_safe.models.RunSecurityAssessmentDetails run_security_assessment_details: (required)
            Details to create an on-demand saved security assessment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.refresh_security_assessment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.refresh_security_assessment(security_assessment_id, run_security_assessment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def refresh_user_assessment_and_wait_for_state(self, user_assessment_id, run_user_assessment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.refresh_user_assessment` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str user_assessment_id: (required)
            The OCID of the user assessment.

        :param oci.data_safe.models.RunUserAssessmentDetails run_user_assessment_details: (required)
            The details required to create an on-demand saved user assessment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.refresh_user_assessment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.refresh_user_assessment(user_assessment_id, run_user_assessment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def set_security_assessment_baseline_and_wait_for_state(self, security_assessment_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.set_security_assessment_baseline` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str security_assessment_id: (required)
            The OCID of the security assessment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.set_security_assessment_baseline`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.set_security_assessment_baseline(security_assessment_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def set_user_assessment_baseline_and_wait_for_state(self, user_assessment_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.set_user_assessment_baseline` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str user_assessment_id: (required)
            The OCID of the user assessment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.set_user_assessment_baseline`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.set_user_assessment_baseline(user_assessment_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def unset_security_assessment_baseline_and_wait_for_state(self, security_assessment_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.unset_security_assessment_baseline` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str security_assessment_id: (required)
            The OCID of the security assessment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.unset_security_assessment_baseline`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.unset_security_assessment_baseline(security_assessment_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def unset_user_assessment_baseline_and_wait_for_state(self, user_assessment_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.unset_user_assessment_baseline` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str user_assessment_id: (required)
            The OCID of the user assessment.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.unset_user_assessment_baseline`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.unset_user_assessment_baseline(user_assessment_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_data_safe_private_endpoint_and_wait_for_state(self, data_safe_private_endpoint_id, update_data_safe_private_endpoint_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.update_data_safe_private_endpoint` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str data_safe_private_endpoint_id: (required)
            The OCID of the private endpoint.

        :param oci.data_safe.models.UpdateDataSafePrivateEndpointDetails update_data_safe_private_endpoint_details: (required)
            The details used to update a Data Safe private endpoint.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.update_data_safe_private_endpoint`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_data_safe_private_endpoint(data_safe_private_endpoint_id, update_data_safe_private_endpoint_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_on_prem_connector_and_wait_for_state(self, on_prem_connector_id, update_on_prem_connector_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.update_on_prem_connector` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str on_prem_connector_id: (required)
            The OCID of the on-premises connector.

        :param oci.data_safe.models.UpdateOnPremConnectorDetails update_on_prem_connector_details: (required)
            The details used to update a on-premises connector.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.update_on_prem_connector`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_on_prem_connector(on_prem_connector_id, update_on_prem_connector_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_on_prem_connector_wallet_and_wait_for_state(self, update_on_prem_connector_wallet_details, on_prem_connector_id, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.update_on_prem_connector_wallet` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param oci.data_safe.models.UpdateOnPremConnectorWalletDetails update_on_prem_connector_wallet_details: (required)
            The details used to update an on-premises connector's wallet.

        :param str on_prem_connector_id: (required)
            The OCID of the on-premises connector.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.update_on_prem_connector_wallet`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_on_prem_connector_wallet(update_on_prem_connector_wallet_details, on_prem_connector_id, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_security_assessment_and_wait_for_state(self, security_assessment_id, update_security_assessment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.update_security_assessment` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str security_assessment_id: (required)
            The OCID of the security assessment.

        :param oci.data_safe.models.UpdateSecurityAssessmentDetails update_security_assessment_details: (required)
            The information to be updated.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.update_security_assessment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_security_assessment(security_assessment_id, update_security_assessment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_target_database_and_wait_for_state(self, target_database_id, update_target_database_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.update_target_database` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str target_database_id: (required)
            The OCID of the Data Safe target database.

        :param oci.data_safe.models.UpdateTargetDatabaseDetails update_target_database_details: (required)
            Details used to update the target database in Data Safe.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.update_target_database`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_target_database(target_database_id, update_target_database_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)

    def update_user_assessment_and_wait_for_state(self, user_assessment_id, update_user_assessment_details, wait_for_states=[], operation_kwargs={}, waiter_kwargs={}):
        """
        Calls :py:func:`~oci.data_safe.DataSafeClient.update_user_assessment` and waits for the :py:class:`~oci.data_safe.models.WorkRequest`
        to enter the given state(s).

        :param str user_assessment_id: (required)
            The OCID of the user assessment.

        :param oci.data_safe.models.UpdateUserAssessmentDetails update_user_assessment_details: (required)
            The information to be updated.

        :param list[str] wait_for_states:
            An array of states to wait on. These should be valid values for :py:attr:`~oci.data_safe.models.WorkRequest.status`

        :param dict operation_kwargs:
            A dictionary of keyword arguments to pass to :py:func:`~oci.data_safe.DataSafeClient.update_user_assessment`

        :param dict waiter_kwargs:
            A dictionary of keyword arguments to pass to the :py:func:`oci.wait_until` function. For example, you could pass ``max_interval_seconds`` or ``max_interval_seconds``
            as dictionary keys to modify how long the waiter function will wait between retries and the maximum amount of time it will wait
        """
        operation_result = self.client.update_user_assessment(user_assessment_id, update_user_assessment_details, **operation_kwargs)
        if not wait_for_states:
            return operation_result

        lowered_wait_for_states = [w.lower() for w in wait_for_states]
        wait_for_resource_id = operation_result.headers['opc-work-request-id']

        try:
            waiter_result = oci.wait_until(
                self.client,
                self.client.get_work_request(wait_for_resource_id),
                evaluate_response=lambda r: getattr(r.data, 'status') and getattr(r.data, 'status').lower() in lowered_wait_for_states,
                **waiter_kwargs
            )
            result_to_return = waiter_result

            return result_to_return
        except Exception as e:
            raise oci.exceptions.CompositeOperationError(partial_results=[operation_result], cause=e)



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from __future__ import absolute_import
import sys
import ctypes
import logging
import os


class DevNull:
    """
    Simple class to supress errors which may occur when importing hashlib
    in FIPS mode.
    """
    def write(self, msg):
        pass


def override_libcrypto(fips_libcrypto_path):
    """
    Override libcrypto and add FIPS_mode function to ssl if it is not there
    """

    _bs_crypto = ctypes.CDLL(fips_libcrypto_path)
    _bs_crypto.FIPS_mode_set(ctypes.c_int(1))
    import ssl  # noqa: E402
    if not hasattr(ssl, 'FIPS_mode'):
        ssl.FIPS_mode = _bs_crypto.FIPS_mode


def md5(intitial_message=''):
    """
    Placeholder md5 function for hashlib so it won't segfault when called after
    enabling FIPS mode.
    """
    raise ValueError("md5 disabled for fips")
    return None


def patch_hashlib_md5():
    """
    hashlib.md5 is imported by urllib3, which is required by requests,
    which is used by oci (python sdk).  This will cause errors so we need to
    patch hashlib.
    """

    stderr = sys.stderr
    try:
        sys.stderr = DevNull()
        import hashlib  # noqa: E402
    except (RuntimeError, ValueError):
        pass
    sys.stderr = stderr
    hashlib.md5 = md5


def is_fips_mode():
    """
    Verify that ssl.FIPS_mode() returns 1 and that using md5 raises an
    exception
    """

    import hashlib
    import ssl

    if not hasattr(ssl, 'FIPS_mode'):
        return False
    elif ssl.FIPS_mode() != 1:
        return False

    try:
        digest = hashlib.md5(b"Hello World\n").hexdigest()  # noqa: F841
        return False
    except ValueError:
        # Expect to get this exception so do nothing
        pass

    return True


def enable_fips_mode(fips_libcrypto_path=None):
    """
    Enable FIPS mode by overriding libcrypto and patching hashlib
    """

    logger = logging.getLogger("{}.{}".format(__name__, id(enable_fips_mode)))
    logger.addHandler(logging.NullHandler())

    if not fips_libcrypto_path:
        if 'FIPS_LIBCRYPTO_PATH' in os.environ:
            fips_libcrypto_path = os.environ['FIPS_LIBCRYPTO_PATH']

    if fips_libcrypto_path:
        override_libcrypto(fips_libcrypto_path)

        import hashlib
        try:
            digest = hashlib.md5(b"Hello World\n").hexdigest()  # noqa: F841

            # If the previous line did not raise an exception md5 needs to be
            # patched
            patch_hashlib_md5()

        except ValueError:
            # Expect to get this exception so do nothing
            pass

        logger.info("Using '{}' for libcypto".format(fips_libcrypto_path))
        if is_fips_mode():
            logger.info("FIPS mode is active")
        else:
            logger.error("Failed to enter FIPS mode")



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class ContainerRepositoryReadme(object):
    """
    Container repository readme.
    """

    #: A constant which can be used with the format property of a ContainerRepositoryReadme.
    #: This constant has a value of "TEXT_MARKDOWN"
    FORMAT_TEXT_MARKDOWN = "TEXT_MARKDOWN"

    #: A constant which can be used with the format property of a ContainerRepositoryReadme.
    #: This constant has a value of "TEXT_PLAIN"
    FORMAT_TEXT_PLAIN = "TEXT_PLAIN"

    def __init__(self, **kwargs):
        """
        Initializes a new ContainerRepositoryReadme object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param content:
            The value to assign to the content property of this ContainerRepositoryReadme.
        :type content: str

        :param format:
            The value to assign to the format property of this ContainerRepositoryReadme.
            Allowed values for this property are: "TEXT_MARKDOWN", "TEXT_PLAIN", 'UNKNOWN_ENUM_VALUE'.
            Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.
        :type format: str

        """
        self.swagger_types = {
            'content': 'str',
            'format': 'str'
        }

        self.attribute_map = {
            'content': 'content',
            'format': 'format'
        }

        self._content = None
        self._format = None

    @property
    def content(self):
        """
        **[Required]** Gets the content of this ContainerRepositoryReadme.
        Readme content. Avoid entering confidential information.


        :return: The content of this ContainerRepositoryReadme.
        :rtype: str
        """
        return self._content

    @content.setter
    def content(self, content):
        """
        Sets the content of this ContainerRepositoryReadme.
        Readme content. Avoid entering confidential information.


        :param content: The content of this ContainerRepositoryReadme.
        :type: str
        """
        self._content = content

    @property
    def format(self):
        """
        **[Required]** Gets the format of this ContainerRepositoryReadme.
        Readme format. Supported formats are text/plain and text/markdown.

        Allowed values for this property are: "TEXT_MARKDOWN", "TEXT_PLAIN", 'UNKNOWN_ENUM_VALUE'.
        Any unrecognized values returned by a service will be mapped to 'UNKNOWN_ENUM_VALUE'.


        :return: The format of this ContainerRepositoryReadme.
        :rtype: str
        """
        return self._format

    @format.setter
    def format(self, format):
        """
        Sets the format of this ContainerRepositoryReadme.
        Readme format. Supported formats are text/plain and text/markdown.


        :param format: The format of this ContainerRepositoryReadme.
        :type: str
        """
        allowed_values = ["TEXT_MARKDOWN", "TEXT_PLAIN"]
        if not value_allowed_none_or_none_sentinel(format, allowed_values):
            format = 'UNKNOWN_ENUM_VALUE'
        self._format = format

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.

from .launch_instance_platform_config import LaunchInstancePlatformConfig
from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class AmdMilanBmLaunchInstancePlatformConfig(LaunchInstancePlatformConfig):
    """
    The platform configuration used when launching a bare metal instance with an E4 shape
    (the AMD Milan platform).
    """

    #: A constant which can be used with the numa_nodes_per_socket property of a AmdMilanBmLaunchInstancePlatformConfig.
    #: This constant has a value of "NPS0"
    NUMA_NODES_PER_SOCKET_NPS0 = "NPS0"

    #: A constant which can be used with the numa_nodes_per_socket property of a AmdMilanBmLaunchInstancePlatformConfig.
    #: This constant has a value of "NPS1"
    NUMA_NODES_PER_SOCKET_NPS1 = "NPS1"

    #: A constant which can be used with the numa_nodes_per_socket property of a AmdMilanBmLaunchInstancePlatformConfig.
    #: This constant has a value of "NPS2"
    NUMA_NODES_PER_SOCKET_NPS2 = "NPS2"

    #: A constant which can be used with the numa_nodes_per_socket property of a AmdMilanBmLaunchInstancePlatformConfig.
    #: This constant has a value of "NPS4"
    NUMA_NODES_PER_SOCKET_NPS4 = "NPS4"

    def __init__(self, **kwargs):
        """
        Initializes a new AmdMilanBmLaunchInstancePlatformConfig object with values from keyword arguments. The default value of the :py:attr:`~oci.core.models.AmdMilanBmLaunchInstancePlatformConfig.type` attribute
        of this class is ``AMD_MILAN_BM`` and it should not be changed.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param type:
            The value to assign to the type property of this AmdMilanBmLaunchInstancePlatformConfig.
            Allowed values for this property are: "AMD_MILAN_BM", "AMD_ROME_BM", "INTEL_SKYLAKE_BM", "AMD_VM", "INTEL_VM"
        :type type: str

        :param is_secure_boot_enabled:
            The value to assign to the is_secure_boot_enabled property of this AmdMilanBmLaunchInstancePlatformConfig.
        :type is_secure_boot_enabled: bool

        :param is_trusted_platform_module_enabled:
            The value to assign to the is_trusted_platform_module_enabled property of this AmdMilanBmLaunchInstancePlatformConfig.
        :type is_trusted_platform_module_enabled: bool

        :param is_measured_boot_enabled:
            The value to assign to the is_measured_boot_enabled property of this AmdMilanBmLaunchInstancePlatformConfig.
        :type is_measured_boot_enabled: bool

        :param numa_nodes_per_socket:
            The value to assign to the numa_nodes_per_socket property of this AmdMilanBmLaunchInstancePlatformConfig.
            Allowed values for this property are: "NPS0", "NPS1", "NPS2", "NPS4"
        :type numa_nodes_per_socket: str

        """
        self.swagger_types = {
            'type': 'str',
            'is_secure_boot_enabled': 'bool',
            'is_trusted_platform_module_enabled': 'bool',
            'is_measured_boot_enabled': 'bool',
            'numa_nodes_per_socket': 'str'
        }

        self.attribute_map = {
            'type': 'type',
            'is_secure_boot_enabled': 'isSecureBootEnabled',
            'is_trusted_platform_module_enabled': 'isTrustedPlatformModuleEnabled',
            'is_measured_boot_enabled': 'isMeasuredBootEnabled',
            'numa_nodes_per_socket': 'numaNodesPerSocket'
        }

        self._type = None
        self._is_secure_boot_enabled = None
        self._is_trusted_platform_module_enabled = None
        self._is_measured_boot_enabled = None
        self._numa_nodes_per_socket = None
        self._type = 'AMD_MILAN_BM'

    @property
    def numa_nodes_per_socket(self):
        """
        Gets the numa_nodes_per_socket of this AmdMilanBmLaunchInstancePlatformConfig.
        The number of NUMA nodes per socket (NPS).

        Allowed values for this property are: "NPS0", "NPS1", "NPS2", "NPS4"


        :return: The numa_nodes_per_socket of this AmdMilanBmLaunchInstancePlatformConfig.
        :rtype: str
        """
        return self._numa_nodes_per_socket

    @numa_nodes_per_socket.setter
    def numa_nodes_per_socket(self, numa_nodes_per_socket):
        """
        Sets the numa_nodes_per_socket of this AmdMilanBmLaunchInstancePlatformConfig.
        The number of NUMA nodes per socket (NPS).


        :param numa_nodes_per_socket: The numa_nodes_per_socket of this AmdMilanBmLaunchInstancePlatformConfig.
        :type: str
        """
        allowed_values = ["NPS0", "NPS1", "NPS2", "NPS4"]
        if not value_allowed_none_or_none_sentinel(numa_nodes_per_socket, allowed_values):
            raise ValueError(
                "Invalid value for `numa_nodes_per_socket`, must be None or one of {0}"
                .format(allowed_values)
            )
        self._numa_nodes_per_socket = numa_nodes_per_socket

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class SortKeyRule(object):
    """
    A rule to define the set of fields to sort by, and whether to sort by ascending or descending values.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new SortKeyRule object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param wrapped_rule:
            The value to assign to the wrapped_rule property of this SortKeyRule.
        :type wrapped_rule: oci.data_integration.models.ProjectionRule

        :param is_ascending:
            The value to assign to the is_ascending property of this SortKeyRule.
        :type is_ascending: bool

        """
        self.swagger_types = {
            'wrapped_rule': 'ProjectionRule',
            'is_ascending': 'bool'
        }

        self.attribute_map = {
            'wrapped_rule': 'wrappedRule',
            'is_ascending': 'isAscending'
        }

        self._wrapped_rule = None
        self._is_ascending = None

    @property
    def wrapped_rule(self):
        """
        Gets the wrapped_rule of this SortKeyRule.

        :return: The wrapped_rule of this SortKeyRule.
        :rtype: oci.data_integration.models.ProjectionRule
        """
        return self._wrapped_rule

    @wrapped_rule.setter
    def wrapped_rule(self, wrapped_rule):
        """
        Sets the wrapped_rule of this SortKeyRule.

        :param wrapped_rule: The wrapped_rule of this SortKeyRule.
        :type: oci.data_integration.models.ProjectionRule
        """
        self._wrapped_rule = wrapped_rule

    @property
    def is_ascending(self):
        """
        Gets the is_ascending of this SortKeyRule.
        Specifies if the sort key has ascending order.


        :return: The is_ascending of this SortKeyRule.
        :rtype: bool
        """
        return self._is_ascending

    @is_ascending.setter
    def is_ascending(self, is_ascending):
        """
        Sets the is_ascending of this SortKeyRule.
        Specifies if the sort key has ascending order.


        :param is_ascending: The is_ascending of this SortKeyRule.
        :type: bool
        """
        self._is_ascending = is_ascending

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other



# coding: utf-8
# Copyright (c) 2016, 2021, Oracle and/or its affiliates.  All rights reserved.
# This software is dual-licensed to you under the Universal Permissive License (UPL) 1.0 as shown at https://oss.oracle.com/licenses/upl or Apache License 2.0 as shown at http://www.apache.org/licenses/LICENSE-2.0. You may choose either license.


from oci.util import formatted_flat_dict, NONE_SENTINEL, value_allowed_none_or_none_sentinel  # noqa: F401
from oci.decorators import init_model_state_from_kwargs


@init_model_state_from_kwargs
class HealthChecksVantagePointSummary(object):
    """
    Information about a vantage point.
    """

    def __init__(self, **kwargs):
        """
        Initializes a new HealthChecksVantagePointSummary object with values from keyword arguments.
        The following keyword arguments are supported (corresponding to the getters/setters of this class):

        :param display_name:
            The value to assign to the display_name property of this HealthChecksVantagePointSummary.
        :type display_name: str

        :param provider_name:
            The value to assign to the provider_name property of this HealthChecksVantagePointSummary.
        :type provider_name: str

        :param name:
            The value to assign to the name property of this HealthChecksVantagePointSummary.
        :type name: str

        :param geo:
            The value to assign to the geo property of this HealthChecksVantagePointSummary.
        :type geo: oci.healthchecks.models.Geolocation

        :param routing:
            The value to assign to the routing property of this HealthChecksVantagePointSummary.
        :type routing: list[oci.healthchecks.models.Routing]

        """
        self.swagger_types = {
            'display_name': 'str',
            'provider_name': 'str',
            'name': 'str',
            'geo': 'Geolocation',
            'routing': 'list[Routing]'
        }

        self.attribute_map = {
            'display_name': 'displayName',
            'provider_name': 'providerName',
            'name': 'name',
            'geo': 'geo',
            'routing': 'routing'
        }

        self._display_name = None
        self._provider_name = None
        self._name = None
        self._geo = None
        self._routing = None

    @property
    def display_name(self):
        """
        Gets the display_name of this HealthChecksVantagePointSummary.
        The display name for the vantage point. Display names are determined by
        the best information available and may change over time.


        :return: The display_name of this HealthChecksVantagePointSummary.
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """
        Sets the display_name of this HealthChecksVantagePointSummary.
        The display name for the vantage point. Display names are determined by
        the best information available and may change over time.


        :param display_name: The display_name of this HealthChecksVantagePointSummary.
        :type: str
        """
        self._display_name = display_name

    @property
    def provider_name(self):
        """
        Gets the provider_name of this HealthChecksVantagePointSummary.
        The organization on whose infrastructure this vantage point resides.
        Provider names are not unique, as Oracle Cloud Infrastructure maintains
        many vantage points in each major provider.


        :return: The provider_name of this HealthChecksVantagePointSummary.
        :rtype: str
        """
        return self._provider_name

    @provider_name.setter
    def provider_name(self, provider_name):
        """
        Sets the provider_name of this HealthChecksVantagePointSummary.
        The organization on whose infrastructure this vantage point resides.
        Provider names are not unique, as Oracle Cloud Infrastructure maintains
        many vantage points in each major provider.


        :param provider_name: The provider_name of this HealthChecksVantagePointSummary.
        :type: str
        """
        self._provider_name = provider_name

    @property
    def name(self):
        """
        Gets the name of this HealthChecksVantagePointSummary.
        The unique, permanent name for the vantage point.


        :return: The name of this HealthChecksVantagePointSummary.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this HealthChecksVantagePointSummary.
        The unique, permanent name for the vantage point.


        :param name: The name of this HealthChecksVantagePointSummary.
        :type: str
        """
        self._name = name

    @property
    def geo(self):
        """
        Gets the geo of this HealthChecksVantagePointSummary.

        :return: The geo of this HealthChecksVantagePointSummary.
        :rtype: oci.healthchecks.models.Geolocation
        """
        return self._geo

    @geo.setter
    def geo(self, geo):
        """
        Sets the geo of this HealthChecksVantagePointSummary.

        :param geo: The geo of this HealthChecksVantagePointSummary.
        :type: oci.healthchecks.models.Geolocation
        """
        self._geo = geo

    @property
    def routing(self):
        """
        Gets the routing of this HealthChecksVantagePointSummary.
        An array of objects that describe how traffic to this vantage point is
        routed, including which prefixes and ASNs connect it to the internet.

        The addresses are sorted from the most-specific to least-specific
        prefix (the smallest network to largest network). When a prefix has
        multiple origin ASNs (MOAS routing), they are sorted by weight
        (highest to lowest). Weight is determined by the total percentage of
        peers observing the prefix originating from an ASN. Only present if
        `fields` includes `routing`. The field will be null if the address's
        routing information is unknown.


        :return: The routing of this HealthChecksVantagePointSummary.
        :rtype: list[oci.healthchecks.models.Routing]
        """
        return self._routing

    @routing.setter
    def routing(self, routing):
        """
        Sets the routing of this HealthChecksVantagePointSummary.
        An array of objects that describe how traffic to this vantage point is
        routed, including which prefixes and ASNs connect it to the internet.

        The addresses are sorted from the most-specific to least-specific
        prefix (the smallest network to largest network). When a prefix has
        multiple origin ASNs (MOAS routing), they are sorted by weight
        (highest to lowest). Weight is determined by the total percentage of
        peers observing the prefix originating from an ASN. Only present if
        `fields` includes `routing`. The field will be null if the address's
        routing information is unknown.


        :param routing: The routing of this HealthChecksVantagePointSummary.
        :type: list[oci.healthchecks.models.Routing]
        """
        self._routing = routing

    def __repr__(self):
        return formatted_flat_dict(self)

    def __eq__(self, other):
        if other is None:
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        return not self == other
